@@ -1,5 +1,5 @@
 /* PgDBF - Quickly convert DBF files to PostgreSQL                       */
-/* Copyright (C) 2008-2010  Kirk Strauser <kirk@daycos.com>              */
+/* Copyright (C) 2008-2011  Kirk Strauser <kirk@strauser.com>            */
 /*                                                                       */
 /* This program is free software: you can redistribute it and/or modify  */
 /* it under the terms of the GNU General Public License as published by  */
@@ -71,6 +71,7 @@ int main(int argc, char **argv)
     char *bufoffset;
     char *s;
     char *t;
+    char *u;
     int  lastcharwasreplaced = 0;
 
     /* Datetime calculation stuff */
@@ -96,15 +97,17 @@ int main(int argc, char **argv)
     int     usecreatetable = 1;
     int     usedroptable = 1;
     int     useifexists = 1;
+    int     usequotedtablename = 0;
     int     usetransaction = 1;
     int     usetruncatetable = 0;
 
     /* Describing the PostgreSQL table */
     char *tablename;
+    char *baretablename;
     char  fieldname[11];
 
     /* Attempt to parse any command line arguments */
-    while((opt = getopt(argc, argv, "cCdDeEhm:tTuU")) != -1) {
+    while((opt = getopt(argc, argv, "cCdDeEhm:qQtTuU")) != -1) {
 	switch(opt) {
 	case 'c':
 	    usecreatetable = 1;
@@ -129,6 +132,12 @@ int main(int argc, char **argv)
 	case 'm':
  	    memofilename = optarg;
 	    break;
+	case 'q':
+	    usequotedtablename = 1;
+	    break;
+	case 'Q':
+	    usequotedtablename = 0;
+	    break;
 	case 't':
 	    usetransaction = 1;
 	    break;
@@ -170,6 +179,8 @@ int main(int argc, char **argv)
 	       "  -E  do not use 'IF EXISTS' when dropping tables (PostgreSQL 8.1 and older)\n"
 	       "  -h  print this message and exit\n"
 	       "  -m  the name of the associated memo file (if necessary)\n"
+	       "  -q  enclose the table name in quotation marks whenever used in statements\n"
+	       "  -Q  do not enclose the table name in quotation marks (default)\n"
 	       "  -t  wrap a transaction around the entire series of statements (default)\n"
 	       "  -T  do not use an enclosing transaction\n"
 	       "  -u  issue a 'TRUNCATE' command before inserting data\n"
@@ -177,7 +188,7 @@ int main(int argc, char **argv)
 	       "\n"
 	       "Using '-u' implies '-C -D'. Using '-c' or '-d' implies '-U'.\n"
 	       "\n"
-	       "%s is copyright 2008-2010 Daycos.\n"
+	       "%s is copyright 2008-2011 kirk@strauser.com.\n"
 	       "License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>\n"
 	       "This is free software: you are free to change and redistribute it.\n"
 	       "There is NO WARRANTY, to the extent permitted by law.\n"
@@ -198,6 +209,15 @@ int main(int argc, char **argv)
     if(tablename == NULL) {
 	exitwitherror("Unable to allocate the tablename buffer", 1);
     }
+    /* The "bare" version of the tablename is the one used by itself in
+     * lines line CREATE TABLE [...], etc. Compare this with tablename which
+     * is used for other things, like creating the names of indexes. Despite
+     * its name, baretablename may be surrounded by quote marks if the "-q"
+     * option for usequotedtablename is given. */
+    baretablename = malloc(strlen(dbffilename) + 1 + usequotedtablename * 2);
+    if(baretablename == NULL) {
+	exitwitherror("Unable to allocate the bare tablename buffer", 1);
+    }
     /* Find the first character after the final slash, or the first
      * character of the filename if no slash is present, and copy from that
      * point to the period in the extension into the tablename string. */
@@ -207,14 +227,21 @@ int main(int argc, char **argv)
 	    break;
 	}
     }
+    /* Create tablename and baretablename at the same time. */
     t = tablename;
+    u = baretablename;
+    if(usequotedtablename) *u++ = '"';
     while(*s) {
 	if(*s == '.') {
 	    break;
 	}
-	*t++ = tolower(*s++);
+	*t = tolower(*s++);
+	*u++ = *t;
+	t++;
     }
+    if(usequotedtablename) *u++ = '"';
     *t = '\0';
+    *u = '\0';
 
     /* Get the DBF header */
     dbffile = fopen(dbffilename, "rb");
@@ -336,14 +363,14 @@ int main(int argc, char **argv)
 	if(useifexists) {
 	    printf(" IF EXISTS");
 	}
-	printf(" %s; SET statement_timeout=0;\n", tablename);
+	printf(" %s; SET statement_timeout=0;\n", baretablename);
     }
 
     /* Generate the create table statement, do some sanity testing, and scan
      * for a few additional output parameters.  This is an ugly loop that
      * does lots of stuff, but extracting it into two or more loops with the
      * same structure and the same switch-case block seemed even worse. */
-    if(usecreatetable) printf("CREATE TABLE %s (", tablename);
+    if(usecreatetable) printf("CREATE TABLE %s (", baretablename);
     printed = 0;
     for(fieldnum = 0; fieldnum < fieldcount; fieldnum++) {
 	if(fields[fieldnum].type == '0') {
@@ -362,20 +389,21 @@ int main(int argc, char **argv)
 	    *t++ = tolower(*s++);
 	}
 	*t = '\0';
-	    
-	 /* If the fieldname is a reserved word, rename it to start with */
-	 /* "tablename_" */
-	isreservedname = 0;
-	for(i = 0; RESERVEDWORDS[i]; i++ ) {
-	    if(!strcmp(fieldname, RESERVEDWORDS[i])) {
-		if(usecreatetable) printf("%s_%s ", tablename, fieldname);
-		isreservedname = 1;
-		break;
+
+	if(usecreatetable) {
+	    /* If the fieldname is a reserved word, rename it to start with
+	     * "tablename_" */
+	    isreservedname = 0;
+	    for(i = 0; RESERVEDWORDS[i]; i++ ) {
+		if(!strcmp(fieldname, RESERVEDWORDS[i])) {
+		    printf("%s_%s ", tablename, fieldname);
+		    isreservedname = 1;
+		    break;
+		}
 	    }
+	    if(!isreservedname) printf("%s ", fieldname);
 	}
-	if(!isreservedname) {
-	    if(usecreatetable) printf("%s ", fieldname);
-	}
+
 	switch(fields[fieldnum].type) {
 	case 'B':
 	    /* Precalculate this field's format string so that it doesn't
@@ -445,11 +473,11 @@ int main(int argc, char **argv)
 
     /* Truncate the table if requested */
     if(usetruncatetable) {
-	printf("TRUNCATE TABLE %s;\n", tablename);
+	printf("TRUNCATE TABLE %s;\n", baretablename);
     }
 
     /* Get PostgreSQL ready to receive lots of input */
-    printf("\\COPY %s FROM STDIN\n", tablename);
+    printf("\\COPY %s FROM STDIN\n", baretablename);
 
     dbfbatchsize = DBFBATCHTARGET / littleint16_t(dbfheader.recordlength);
     if(!dbfbatchsize) {
@@ -639,10 +667,11 @@ int main(int argc, char **argv)
 		}
 	    }
 	}
-	printf(" ON %s(%s);\n", tablename, argv[i]);
+	printf(" ON %s(%s);\n", baretablename, argv[i]);
     }
 
     free(tablename);
+    free(baretablename);
     free(fields);
     for(fieldnum = 0; fieldnum < fieldcount; fieldnum++) {
 	if(pgfields[fieldnum].formatstring != NULL) {
